function J=Jacobian(R,q)

% This function computes the Jacobian matrix for the backhoe
% based on the link dimensions and joint angles

% Extract link lengths from R matrix
a1=R(1,1);
a2=R(2,2);
a3=R(3,3);
a4=R(4,1);

% Define joint angles
q1=q(1);
q2=q(2);
q3=q(3);
q4=q(4);

% Unit vectors
z0=[0 0 1]';
z1=[sin(q1) -cos(q1) 0]';
z2=z1;
z3=z1;

% Define vectors from base frame origin to origins 1-3
p0=[0 0 0]';
p1=[a1*cos(q1) a1*sin(q1) 0]';
p2=p1+[a2*cos(q2)*cos(q1) a2*cos(q2)*sin(q1) a2*sin(q2)]';
p3=p2+[a3*cos(q2+q3)*cos(q1) a3*cos(q2+q3)*sin(q1) a3*sin(q2+q3)]';
p4=p3+[a4*cos(q2+q3+q4)*cos(q1) a4*cos(q2+q3+q4)*sin(q1) a4*sin(q2+q3+q4)]';

% Choose O4 as end-effector
p=p4;

% Compute Jacobian
J=[cross(z0,p-p0) cross(z1,p-p1) cross(z2,p-p2) cross(z3,p-p3);
   z0 z1 z2 z3];