function [sys,x0,str,ts] = SCrod(t,x,u,flag,Ar,Cr,yc0,pr0)

% This function computes the cap-side cylinder pressures based upon the difference 
% in flow and rod displacement volumes, and the compliance of the cylinders and hoses 

% Switch based upon the current flag value
switch flag,
  case 0,
    [sys,x0,str,ts]=mdlInitializeSizes;
  case 3,
    sys=mdlOutputs(t,x,u,Ar,Cr,yc0,pr0);
  case {1,2,4,9}
    sys=[];
  otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

% end SCrod
%
%======================
% mdlInitializeSizes
%======================
%
function [sys,x0,str,ts]=mdlInitializeSizes

sizes = simsizes;

sizes.NumContStates  = 0;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = 4;
sizes.NumInputs      = 9;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
x0  = [];
str = [];
ts  = [0 0];

% end mdlInitializeSizes

%========================
% mdlOutputs
%========================
%
function sys=mdlOutputs(t,x,u,Ar,Cr,yc0,pr0)

DVr=u(1:4);
yc=[u(5);u(7:9)];

yct=yc-[yc0(1);yc0(3:5)];

pr=(DVr+yct.*Ar)./Cr'+pr0';

sys = pr;

% end mdlOutputs