function [sys,x0,str,ts] = SFdisp(t,x,u,flag,a)

% This function computes end-effector displacement from the joint angles

% Switch based upon the current flag value
switch flag,
  case 0,
    [sys,x0,str,ts]=mdlInitializeSizes;
  case 3,
    sys=mdlOutputs(t,x,u,a);
  case {1,2,4,9}
    sys=[];
  otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

% end SFdisp
%
%======================
% mdlInitializeSizes
%======================
%
function [sys,x0,str,ts]=mdlInitializeSizes

sizes = simsizes;

sizes.NumContStates  = 0;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = 4;
sizes.NumInputs      = 4;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
x0  = [];
str = [];
ts  = [0 0];

% end mdlInitializeSizes
%
%========================
% mdlOutputs
%========================
%
function sys=mdlOutputs(t,x,u,a)

q=u;
alpha=[pi/2 0 0 0];
d=[0 0 0 0];

% Compute Homogeneous Transformation Matrices
for i=1:4
   st=sin(q(i));
   ct=cos(q(i));
   sa=sin(alpha(i));
   ca=cos(alpha(i));
   A{i}=[ct -st*ca st*sa a(i)*ct;
      st ct*ca -ct*sa a(i)*st;
      0 sa ca d(i);
      0 0 0 1];
end

% Compute overall transformation matrix
Y04=A{1}*A{2}*A{3}*A{4};

% Compute bucket angle phi
R12=Rz(q(2));
R23=Rz(q(3));
R34=Rz(q(4));
R14=R12*R23*R34;
X=R14(1,1);
Y=R14(2,1);
theta=atan2(Y,X);
if X < 0 & Y > 0 			% atan2 in 2nd quadrant
   phi=theta-pi;
else							% atan2 in 1st, 3rd, or 4th quadrant
   phi=theta+pi;			
end

% Assemble output
ye=[Y04(1,4) Y04(2,4) Y04(3,4) phi]';

sys = ye;

% end mdlOutputs
