function [sys,x0,str,ts] = Sfunc(t,x,u,flag,M11,M12,M13,M14,M21,M22,M23,M24,M31,M32,M33,M34,M41,M42,M43,M44,V1,V2,V3,V4,G1,G2,G3,G4)

% This function computes the joint accelerations

% Switch based upon the current flag value
switch flag,
  case 0,
    [sys,x0,str,ts]=mdlInitializeSizes;
  case 3,
    sys=mdlOutputs(t,x,u,M11,M12,M13,M14,M21,M22,M23,M24,M31,M32,M33,M34,M41,M42,M43,M44,V1,V2,V3,V4,G1,G2,G3,G4);
  case {1,2,4,9}
    sys=[];
  otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

% end Sfunc
%
%======================
% mdlInitializeSizes
%======================
%
function [sys,x0,str,ts]=mdlInitializeSizes

sizes = simsizes;

sizes.NumContStates  = 0;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = 4;
sizes.NumInputs      = 12;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
x0  = [];
str = [];
ts  = [0 0];

% end mdlInitializeSizes
%
%========================
% mdlOutputs
%========================
%
function sys=mdlOutputs(t,x,u,M11,M12,M13,M14,M21,M22,M23,M24,M31,M32,M33,M34,M41,M42,M43,M44,V1,V2,V3,V4,G1,G2,G3,G4)

taus=u(1:4);
q=u(5:8);
qd=u(9:12);

% Convert units of torque from [lbf*in] to [lbm*in^2/s^2]
gc=32.174*12;
taus=taus*gc;

% Use string expressions from workspace to evaluate 
% the current value of the dynamic model elements
M=zeros(4,4);
V=zeros(4,1);
G=zeros(4,1);

M(1,1)=eval(M11);
M(1,2)=eval(M12);
M(1,3)=eval(M13);
M(1,4)=eval(M14);
M(2,1)=eval(M21);
M(2,2)=eval(M22);
M(2,3)=eval(M23);
M(2,4)=eval(M24);
M(3,1)=eval(M31);
M(3,2)=eval(M32);
M(3,3)=eval(M33);
M(3,4)=eval(M34);
M(4,1)=eval(M41);
M(4,2)=eval(M42);
M(4,3)=eval(M43);
M(4,4)=eval(M44);

V(1)=eval(V1);
V(2)=eval(V2);
V(3)=eval(V3);
V(4)=eval(V4);

G(1)=eval(G1);
G(2)=eval(G2);
G(3)=eval(G3);
G(4)=eval(G4);

qdd=inv(M)*(taus-V-G);

sys = qdd;

% end mdlOutputs
