function [sys,x0,str,ts] = SRtorque(t,x,u,flag,R)

% This function calls the Jacobian routine and then computes the joint torques
% required for the end-effector wrench

% Switch based upon the current flag value
switch flag,
  case 0,
    [sys,x0,str,ts]=mdlInitializeSizes;
  case 3,
    sys=mdlOutputs(t,x,u,R);
  case {1,2,4,9}
    sys=[];
  otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

% end SRtorque
%
%======================
% mdlInitializeSizes
%======================
%
function [sys,x0,str,ts]=mdlInitializeSizes

sizes = simsizes;

sizes.NumContStates  = 0;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = 4;
sizes.NumInputs      = 10;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
x0  = [];
str = [];
ts  = [0 0];

% end mdlInitializeSizes
%
%========================
% mdlOutputs
%========================
%
function sys=mdlOutputs(t,x,u,R)

q=u(1:4);
We=u(5:10);

J=Jacobian(R,q);
taue=J'*We;

sys = taue;

% end mdlOutputs
