function [sys,x0,str,ts] = Sjoint_to_cyl(t,x,u,flag,R,yc0)

% This function computes the required cylinder lengths for a 
% given set of joint angles

% Switch based upon the current flag value
switch flag,
  case 0,
    [sys,x0,str,ts]=mdlInitializeSizes;
  case 3,
    sys=mdlOutputs(t,x,u,R,yc0);
  case {1,2,4,9}
    sys=[];
  otherwise
    error(['Unhandled flag = ',num2str(flag)]);
end

% end Sjoint_to_cyl
%
%======================
% mdlInitializeSizes
%======================
%
function [sys,x0,str,ts]=mdlInitializeSizes

sizes = simsizes;

sizes.NumContStates  = 0;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = 5;
sizes.NumInputs      = 4;
sizes.DirFeedthrough = 0;
sizes.NumSampleTimes = 1;   % at least one sample time is needed

sys = simsizes(sizes);
x0  = [];
str = [];
ts  = [0 0];

% end mdlInitializeSizes

%========================
% mdlOutputs
%========================
%
function sys=mdlOutputs(t,x,u,R,yc0)

q=u;
% Extract relevant dimensions from the 4x14 R matrix
%
%        1   2   3   4   5   6   7    8     9       10      11	  12   13   14
% 1  R=[R01 R0N RAN RJM R1A R0M R0K  R0J  p11K(1) p11K(2) p11K(3) T01A T10K TMJ0;
% 2     R1C R12 R2C R1B R2B 0   0    0    0       0       0       TB12 T12C 0;
% 3     R2D RDE R23 R2E R3D REF RDF  R3F  0       0       0       TD23 TDFE T23D;
% 4     R34 R3G R4G RFH RGH 0   0    0    0       0       0       TG34 0    0;];

%1.
R0M=R(1,6);
RJM=R(1,4);
p11K3=R(1,11);
R0J=R(1,8);
R0K=R(1,7);
T10K=R(1,13);

%2.
T01A=R(1,12);
TB12=R(2,12);
R1A=R(1,5);
R1B=R(2,4);

%3.
TD23=R(3,12);
T12C=R(2,13);
R2C=R(2,3);
R2D=R(3,1);

%4.
TG34=R(4,12);
T23D=R(3,14);
R3F=R(3,5)-R(3,7);
R3G=R(4,2);
RGH=R(4,5);
RFH=R(4,4);
TDFE=R(3,13);
REF=R(3,6);

% ========= PART 1: Compute Swing Cylinder Lengths yra=yr(1) and yrb=yr(2) from q(1) ========

%TQ0J=atan(R0M/RJM)+q(1);
%TK0J=TQ0J+pi/2-T10K;
%yc(1)=sqrt(R0J^2+R0K^2-2*R0J*R0K*cos(TK0J));
%TJp0Qp=atan(R0M/RJM)-q(1);
%TJp0Kp=TJp0Qp+pi/2-T10K;
%yc(2)=sqrt(R0J^2+R0K^2-2*R0J*R0K*cos(TJp0Kp));
%**************************************************************
%                   TEMP FIX SECTION    
% ***Approximate moment arm of swing cylinders as a constant***
r=RJM-p11K3;
yc(1)=yc0(1)+r*q(1);
yc(2)=yc0(2)-r*q(1);
% see also "SFr2taur", "cylinders"
%**************************************************************

% ========= PART 2: Compute Boom Cylinder Length yr(3) from q(2) ========

TA1B=pi-T01A-TB12-q(2);
yc(3)=sqrt(R1A^2+R1B^2-2*R1A*R1B*cos(TA1B));

% ========= PART 3: Compute Stick Cylinder Length yr(4) from q(3) ========

T321=q(3)-pi;
TC2D=2*pi-TD23-T321-T12C;
yc(4)=sqrt(R2C^2+R2D^2-2*R2C*R2D*cos(TC2D));

% ========= PART 4: Compute Bucket Cylinder Length yr(5) from q(4) ========

Tx33G=2*pi-q(4)-TG34;
TG3F=pi-Tx33G+T23D;
RFG=sqrt(R3F^2+R3G^2-2*R3F*R3G*cos(TG3F));
T3FG=acos((R3F^2+RFG^2-R3G^2)/(2*R3F*RFG));
THFG=acos((RFG^2+RFH^2-RGH^2)/(2*RFG*RFH));
if q(4)+TG34>2*pi
   THF3=THFG+T3FG;
else
   THF3=THFG-T3FG;
end
TEFH=pi-TDFE-THF3;
yc(5)=sqrt(REF^2+RFH^2-2*REF*RFH*cos(TEFH));
sys = real(yc)';

% end mdlOutputs
