%======================================================================
%
%           BACKHOE SIMULATION
%
%
% 				Joe Frankel
%				Spring 2004
%
%
% This program generates variables and places them into the workspace
% for preparing to run the Simulink model "backhoe_sim.mdl"
%
%======================================================================

clear all; close all; clc;

% ================= PUMP & TANK PARAMETERS ================
QP=33.11;
pT=0;

% ==================== VALVE PARAMETERS ===================
load PVG32param

% ================ HOSE & CYLINDER PARAMETERS =============

% Cylinder areas, cylinder & hose capacitances
pbar=[0 0 0 0;   % <-- cap-side (A) operating points [psi]
   0 0 0 0];		% <-- rod-side (B) operating points [psi]
[Lcyl,Lrod,Ac,Ar,Cc,Cr]=cylinders(pbar);

% Pressure relief settings
prelief=2250; % [psi]

% Cylinder limitations
R=dimensions(1);
yclim=[15.25   27.26       27.25 	23.375;  	% <- minimums
       23.85   44.625 		44.61 	35.41]; 	% <- maximums
qmin=cyl_to_joint([yclim(1,1) yclim(1,1) yclim(2,2) yclim(2,3) yclim(2,4)],R);
qmax=cyl_to_joint([yclim(2,1) yclim(2,1) yclim(1,2) yclim(1,3) yclim(1,4)],R);
qmin(1)=-pi/2;qmin(3)=3.7;
qmax(1)=pi/2;

ProEqmin=[qmin(1);qmin(2);qmin(3)-2*pi;qmin(4)-2*pi]*180/pi;
ProEqmax=[qmax(1);qmax(2);qmax(3)-2*pi;qmax(4)-2*pi]*180/pi;

% ================ BACKHOE PARAMETERS ===============

% Link dimensions
a=[R(1,1) R(2,2) R(3,3) R(4,1)];
zg=13; % height of base frame origin o0 above ground level
g=1;
q1c=R(1,15);

% mass vector, COM position vectors, principle link inertias
[m,pCOM,ICOM]=masses(a);

% Place matrix and vector elements of LaGrangian dynamic model into the workspace
[M11,M12,M13,M14,M21,M22,M23,M24,M31,M32,M33,M34,M41,M42,M43,M44...
      ,V1,V2,V3,V4,G1,G2,G3,G4]=sub_static_vars(m,pCOM,ICOM,a,g);

% Joint damping (assume net sum from joints, cylinders, etc.)
bq=[1000 1000 1000 1000]; %[lbf*in*s/rad]


% ================== DESIRED OUTPUT VECTORS ================

% Simulation time and number of desired trajectory points
tfinal=30;
N=3000;

% Set home position and retreive desired 5xN twist trajectory

% ==================== INITIAL CONDITIONS ======================

% Initial Conditions for e-e, joystick, joints, cylinders
%ye0=ydes(1,:)';								% bucket starting position relative to o0
%ym0=[ye0(1)/Kscale 0 ye0(2)/Kscale ...	% joystick starting position
%    0 ye0(3)/Kscale 0 ye0(4) 0]';		
%home=[20 0 2 -10*pi/180];
%q0=Rdisp(home,a)';								% initial joint angles
%yc0=joint_to_cyl(R,q0)';					% initial cylinder lengths
yc0=[21.587 21.587 28.9 45.27 36.195]';
q0=cyl_to_joint(yc0,R)

% Static joint torques required to hold backhoe in equilibrium
taust=-statictorque(q0,m,pCOM,a,g);
Fr0=tau2Fr(taust,q0,yc0,R);

% Static cylinder pressures required to hold backhoe in equilibrium
[pc0,pr0]=staticpressure(taust,yc0,Ac,Ar,R);

ProEqstart=[q0(1);q0(2);q0(3)-2*pi;q0(4)-2*pi]*180/pi;

save backhoe_param R a Ac Ar Cc Cr m pCOM ICOM yc0 q0 qmax qmin...
	M11 M12 M13 M14 M21 M22 M23 M24 M31 M32 M33 M34 M41 M42 M43 M44...
   V1 V2 V3 V4 G1 G2 G3 G4 pc0 pr0 prelief QP pT yc0 Lcyl Lrod