function q=cyl_to_joint(yc,R)

%*******************************************
%     TEMP VALUES - DELETE WHEN FINISHED
%clear all; close all; clc;
%R=dimensions(1);
%yc=[23.851   29      27.6990 22.0242]';

%*******************************************

% This function computes the joint angles of the backhoe based on
% cylinder positions measurements and link dimensions

% Extract necessary dimensions from R matrix
%
%        1   2   3   4   5   6   7    8     9       10      11	  12   13   14
% 1  R=[R01 R0N RAN RJM R1A R0M R0K  R0J  p11K(1) p11K(2) p11K(3) T01A T10K TMJ0 q1c;
% 2     R1C R12 R2C R1B R2B 0   0    0    0       0       0       TB12 T12C 0 	0;
% 3     R2D RDE R23 R2E R3D REF RDF  R3F  0       0       0       TD23 TDFE T23D 0;
% 4     R34 R3G R4G RFH RGH 0   0    0    0       0       0       TG34 0    0 	0;];

R01=R(1,1);
RJM=R(1,4);
R1A=R(1,5);
R0M=R(1,6);
R0K=R(1,7);
R1B=R(2,4);
T01A=R(1,12);
TB12=R(2,12);
R2C=R(2,3);
R2D=R(3,1);
T12C=R(2,13);
TD23=R(3,12);
REF=R(3,6);
RFH=R(4,4);
TDFE=R(3,13);
R3F=R(3,5)-R(3,7);
R3G=R(4,2);
RGH=R(4,5);
TG34=R(4,12);
R23=R(3,3);
R3D=R(3,5);
p11Kx=R(1,9);
p11Ky=R(1,10);
p11Kz=R(1,11);

% Expand cylinder lengths from Rc vector
RJK=yc(1);
RAB=yc(3);
RCD=yc(4);
REH=yc(5);

% 1. Compute q(1) from Swing Cylinder measurement yr(1)
R0J=sqrt(RJM^2+R0M^2);
TK0Q=atan((R01+p11Kx)/p11Kz);
TMJ0=atan(R0M/RJM);
TK0J=acos((R0K^2+R0J^2-yc(1)^2)/(2*R0K*R0J));
q(1)=TK0J-TK0Q-TMJ0;

% 2. Compute q(2) from Boom Cylinder measurement yr(2)
TA1B=acos((R1A^2+R1B^2-RAB^2)/(2*R1A*R1B));
q(2)=pi-T01A-TA1B-TB12;

% 3. Compute q(3) from Stick Cylinder measurement yr(3)
TC2D=acos((R2C^2+R2D^2-RCD^2)/(2*R2C*R2D));
q(3)=3*pi-T12C-TC2D-TD23;

% 4. Compute q(4) from Bucket Cylinder measurement yr(4)
TEFH=acos((REF^2+RFH^2-REH^2)/(2*REF*RFH));
THF3=pi-TDFE-TEFH;
R3H=sqrt(R3F^2+RFH^2-2*R3F*RFH*cos(THF3));
TF3H=acos((R3F^2+R3H^2-RFH^2)/(2*R3F*R3H));
TH3G=acos((R3H^2+R3G^2-RGH^2)/(2*R3H*R3G));
T23D=acos((R23^2+R3D^2-R2D^2)/(2*R23*R3D));
q(4)=3*pi-TF3H-TH3G-TG34-T23D;

% Verification section: use to check computed angles w/drawings
%TA1B=TA1B*180/pi
%q2=q(2)*180/pi

%TC2D=TC2D*180/pi
%q3=q(3)*180/pi

%TEFH=TEFH*180/pi
%TDFE=TDFE*180/pi
%THF3=THF3*180/pi
%TF3H=TF3H*180/pi
%TH3G=TH3G*180/pi
%q4=q(4)*180/pi 