function [Lcyl,Lrod,Ac,Ar,Cc,Cr]=cylinders(pbar)

% This function outputs the effective areas and fluid capacitances 
% of the cylinder and hose volumes,
% separately for the cap and rod side for each cylinder

% Thickness of cylinder walls [in]
tcyl=[0.15 0.1895 0.1895 0.1905]';

% Cylinder outside diameters [in]
Dco=[2.125 2.879 2.879 2.381]';

% Cylinder inside diameters [in]
Dc=[1.55 2.5 2.5 2]';

% Rod Diameters [in]
Dr=[1 1.25 1.25 1.125]';

% Cap and rod areas [in^2]
Ac=pi*(Dc.^2)/4;
Ar=Ac-pi*(Dr.^2)/4;

%**************************************************************
%                   TEMP FIX SECTION    
% ***Approximate moment arm of swing cylinders as a constant***
%Ac(1)=2*Ac(1);
%Ar(1)=2*Ar(1);
% see also "Sjoint_to_cyl", "SFr2taur"
%**************************************************************

% Overall cylinder and rod lengths [in]
Lcyl=[12.5*2 25 25.5 21.5]';
Lrod=[15 30 30 25]';

% Young's Modulus of cylinder wall material [lbf/in^2]
Ecyl=30e6*ones(4,1);

% Rod masses [lbm]
mr=[20 50 50 50]';

% Cylinder friction [lbf*s/in]
bcyl=[1 1 1 1]';

% Inside hose diameters [in]
Dh=[0.375 0.375 0.375 0.375; % <--cap-side (A) diameters
   0.375 0.375 0.375 0.375]; % <--rod-side (B) diameters

% Hose Lengths
Lh=[36 36 36 36; % <--cap-side (A) lengths
   36 36 36 36]; % <--rod-side (B) lengths

% Hose wall thicknesses
th=0.15*ones(2,4);

% Young's modulus of hose material
Eh=5e5*ones(2,4);

% Oil bulk modulus [lbf/in^2]
Beta=225e3; 
%Beta=150e3; 

% ======================== Calculations ==========================

% Cap and rod-side fluid capacitances 
% NOTE: approximating assumption yc is halfway down travel length!
for i=1:4  
   
   % Cap-side cylinder volumes
   Vc(i)=Ac(i)*Lcyl(i)/2;
   
   % Cap-side hose volumes
   Vhosec(i)=(pi/4)*Dh(1,i)^2*Lh(1,i);
   
   % Cap-side cylinder capacitances
   dVcylcdp(i)=((pi*(Lcyl(i)/2)*Dc(i)^3)/(4*tcyl(i)*Ecyl(i)))...
      *(1+(pbar(1,i)*Dc(i))/(2*tcyl(i)*Ecyl(i)));
   
   % Cap-side hose capacitances
   dVhosecdp(i)=((pi*Lh(1,i)*Dh(1,i)^3)/(4*th(1,i)*Eh(1,i)))...
      *(1+(pbar(1,i)*Dh(1,i))/(2*th(1,i)*Eh(1,i)));   
   
   % Total cap-side capacitances
   Cc(i)=(Vc(i)+Vhosec(i))/Beta+dVcylcdp(i)+dVhosecdp(i);
   Cf=(Vc(i)+Vhosec(i))/Beta;
   Cy=dVcylcdp(i);
   Ch=dVhosecdp(i);
   
   % Rod-side cylinder volumes
   Vr(i)=Ar(i)*Lcyl(i)/2;
   
   % Rod-side hose volumes

   Vhoser(i)=(pi/4)*Dh(2,i)^2*Lh(2,i);

   
   % Rod-side cylinder capacitances   
   dVcylrdp(i)=((pi*(Lcyl(i)/2)*Dr(i)^3)/(4*tcyl(i)*Ecyl(i)))...
      *(1+(pbar(2,i)*Dr(i))/(2*tcyl(i)*Ecyl(i)));
   
   % Rod-side hose capacitances   
   dVhoserdp(i)=((pi*Lh(2,i)*Dh(2,i)^3)/(4*th(2,i)*Eh(2,i)))...
      *(1+(pbar(2,i)*Dh(2,i))/(2*th(2,i)*Eh(2,i)));
   
   % Total rod-side capacitances   
   Cr(i)=(Vr(i)+Vhoser(i))/Beta+dVcylrdp(i)+dVhoserdp(i);
   
end