% This file plots the digging trajectory input/ouput data for each cylinder

clear all ; close all ; clc ;

load dig_sim

% ================= READ DATA =====================
% read time into vectors
t=dig_time';
t_th=data_th(:,1);

% read desired references into vectors
q1des=ycdes(:,1)*180/pi;
yc3des=ycdes(:,2);
yc4des=ycdes(:,3);
yc5des=ycdes(:,4);

% read measured valve commands into vectors
Us1=dig_data(:,1);
Us2=dig_data(:,2);
Us3=dig_data(:,3);
Us4=dig_data(:,4);

% read simulated valve commands into vectors
Us1_th=data_th(:,2);
Us2_th=data_th(:,3);
Us3_th=data_th(:,4);
Us4_th=data_th(:,5);

% read measured output into vectors
q1=dig_data(:,5)*180/pi;
yc3=dig_data(:,6);
yc4=dig_data(:,7);
yc5=dig_data(:,8);

% read simulated output into vectors
q1_th=data_th(:,6)*180/pi;
yc3_th=data_th(:,7);
yc4_th=data_th(:,8);
yc5_th=data_th(:,9);

clear data_th dig_data dig_time traj ycdes

% define colors
lgreen=[7,255,1]/255;
dgreen=[15,84,10]/255;
purple=[66,27,145]/255;
burgundy=[114,8,28]/255;
sea=[18,104,53]/255;

% ============ PLOT INPUT ================
figure
% plot the swing valve commands
subplot(4,2,1)
plot(t,Us1,'color',dgreen,'linewidth',2)
hold on
plot(t_th,Us1_th,'--','color',lgreen,'linewidth',2)
plot([t(1) t(end)],[6 6],'k')
ylim([2.5 9.5])
xlim([0 60])
ylabel('swing command [V]')
title('Swing joint')

% plot the boom valve commands
subplot(4,2,2)
plot(t,Us2,'color',dgreen,'linewidth',2)
hold on
plot(t_th,Us2_th,'--','color',lgreen,'linewidth',2)
plot([t(1) t(end)],[6 6],'k')
ylim([2.5 9.5])
xlim([0 60])
ylabel('boom command [V]')
title('Boom cylinder')

% plot the stick valve commands
subplot(4,2,5)
plot(t,Us3,'color',dgreen,'linewidth',2)
hold on
plot(t_th,Us3_th,'--','color',lgreen,'linewidth',2)
plot([t(1) t(end)],[6 6],'k')
ylim([2.5 9.5])
xlim([0 60])
ylabel('stick command [V]')
title('Stick cylinder')

% plot the bucket valve commands
subplot(4,2,6)
plot(t,Us4,'color',dgreen,'linewidth',2)
hold on
plot(t_th,Us4_th,'--','color',lgreen,'linewidth',2)
plot([t(1) t(end)],[6 6],'k')
ylim([2.5 9.5])
xlim([0 60])
ylabel('bucket command [V]')
title('Bucket cylinder')

clear Us1 Us2 Us3 Us4 Us1_th Us2_th Us3_th Us4_th 

% ============ PLOT OUTPUT ===============
%figure
% plot the swing data
subplot(4,2,3)
plot(t,q1des,'b--','linewidth',2)
hold on
plot(t,q1,'r','linewidth',2)
plot(t_th,q1_th,'m--','linewidth',2)
ylabel('angle [deg]')
ylim([-5 18])
xlim([0 60])

% plot the boom data
subplot(4,2,4)
plot(t,yc3des,'b--','linewidth',2)
hold on
plot(t,yc3,'r','linewidth',2)
plot(t_th,yc3_th,'m--','linewidth',2)
ylabel('length [in]')
ylim([26 32])
xlim([0 60])

% plot the stick data
subplot(4,2,7)
plot(t,yc4des,'b--','linewidth',2)
hold on
plot(t,yc4,'r','linewidth',2)
plot(t_th,yc4_th,'m--','linewidth',2)
ylabel('length [in]')
ylim([35 48])
xlim([0 60])
xlabel('time [s]')

% plot the bucket data
subplot(4,2,8)
plot(t,yc5des,'b--','linewidth',2)
hold on
plot(t,yc5,'r','linewidth',2)
plot(t_th,yc5_th,'m--','linewidth',2)
ylabel('length [in]')
xlabel('time [s]')
ylim([25 38])
xlim([0 60])

% input legend
subplot(4,2,1)
legend('input data','model input','neutral',2)

% output legend
subplot(4,2,3)
legend('position reference','output data','model output',2)