function R=dimensions(a) 

% ======================= LINK DIMENSIONS ==========================
% All dimensions in inches. Note that only center-to-center joint 
% distances ar required. See drawings for dimensions and point labels.

% Ouput matrix format:
%        1   2   3   4   5   6   7    8     9       10      11	  12   13   14
% 1  R=[R01 R0N RAN RJM R1A R0M R0K  R0J  p11K(1) p11K(2) p11K(3) T01A T10K TMJ0 q1c;
% 2     R1C R12 R2C R1B R2B 0   0    0    0       0       0       TB12 T12C 0 	0;
% 3     R2D RDE R23 R2E R3D REF RDF  R3F  0       0       0       TD23 TDFE T23D 0;
% 4     R34 R3G R4G RFH RGH 0   0    0    0       0       0       TG34 0    0 	0;];

% ----Link 1 (Base)----

% Dimension constants from length measurements 
R01=8.5;
R0N=10.5;
RAN=7.5;
RJM=8;
R0M=17.5;
p11K=[-5 2 3]; % distance from origin 1 to K in frame 1

% Calculated interior angle and dimension constants
R0J=sqrt(R0M^2+RJM^2);
R0K=sqrt((R01+p11K(1))^2+p11K(3)^2);
R1A=sqrt(R0N^2+(R01-RAN)^2);
T01A=atan(R0N/(R01-RAN));
T10K=atan(p11K(3)/(R01+p11K(1)));
TMJ0=atan(R0M/RJM);
q1c=pi/2-atan(R0M/RJM)+asin(p11K(3)/R0J); % swing critical over-center angle

% ----Link 2 (Boom)----

% Dimension constants from length measurements 
R1C=17.5;
R12=48;
R2C=36;
R1B=35.875;
R2B=12+5/16;

% Calculated interior angle and dimension constants
TB12=acos((R1B^2+R12^2-R2B^2)/(2*R1B*R12));
T12C=acos((R12^2+R2C^2-R1C^2)/(2*R12*R2C));

% ----Link 3 (Stick)----

% Dimension constants from length measurements 
R2D=9+7/8;
RDE=13;
R23=38.5;
R2E=8.625;
R3D=47.25;
REF=30.77;
R3F=4.5;

% Calculated interior angle and dimension constants
RDF=R3D-R3F;
TD23=acos((R2D^2+R23^2-R3D^2)/(2*R2D*R23));
TDFE=acos((RDF^2+REF^2-RDE^2)/(2*RDF*REF));
T23D=acos((R23^2+R3D^2-R2D^2)/(2*R23*R3D));

% ----Link 4 (Bucket)----

% Dimension constants from length measurements 
R34=18.5;
R3G=5.5;
R4G=19;

% Calculated interior angle and dimension constants
TG34=acos((R3G^2+R34^2-R4G^2)/(2*R3G*R34));

% ----Bucket sub-links----
RFH=9.5;
RGH=9.5;

% Place all dimensions and angles into matrix R
% --Columns 1-7 are lengths [in]
% --Columns 8-9 are angles [rad]
% --Row(i) contains dimensions for Link(i)
%
%   1   2   3   4   5   6   7    8      9      10   	11	    12   13   14
R=[R01 R0N RAN RJM R1A R0M R0K  R0J  p11K(1) p11K(2) p11K(3) T01A T10K TMJ0 q1c;
   R1C R12 R2C R1B R2B 0   0    0    0       0       0       TB12 T12C 0 0;
   R2D RDE R23 R2E R3D REF RDF  R3F  0       0       0       TD23 TDFE T23D 0;
   R34 R3G R4G RFH RGH 0   0    0    0       0       0       TG34 0    0 0;];

% Output angle dimensions in degrees if desired
%Rd=[R(:,1:7) R(:,8:9)*180/pi];