function taustatic=statictorque(q,m,pCOM,a,g)

% This function computes the static joint torques caused by the weight
% of the links.

% Note that the tractor base frame z0 is assumed to be aligned normal to 
% the earth, otherwise R0E (E=Earth) would not be identity

R0E=eye(3); % Rotation from earth to tractor base, where zE points stright up

% Extract input quantities
q1=q(1);q2=q(2);q3=q(3);q4=q(4);
m1=m(1);m2=m(2);m3=m(3);m4=m(4);
g0=R0E*[0;0;-g];

% COM vectors
p1o0c1=pCOM(1,:)';
p2o1c2=pCOM(2,:)';
p3o2c3=pCOM(3,:)';
p4o3c4=pCOM(4,:)';

% Link length vectors
p1o0o1=[a(1);0;0];
p2o1o2=[a(2);0;0];
p3o2o3=[a(3);0;0];

% Rotation Matrices
Rx90=[1 0 0;0 0 -1;0 1 0];
Ry1=[cos(q1) 0 sin(q1);0 1 0;-sin(q1) 0 cos(q1)];
R01=Rx90*Ry1;

R12=[cos(q2) -sin(q2) 0;sin(q2) cos(q2) 0;0 0 1];
R02=R01*R12;

R23=[cos(q3) -sin(q3) 0;sin(q3) cos(q3) 0;0 0 1];
R03=R02*R23;

R34=[cos(q4) -sin(q4) 0;sin(q4) cos(q4) 0;0 0 1];
R04=R03*R34;

% Z-axis vectors
z=[0;0;1];
z00=z;z01=R01*z;z02=R02*z;z03=R03*z;z04=R04*z;

% Compute static joint torques
taustatic(1)=dot(cross(R01*p1o0c1,m1*g0)+cross((R01*p1o0o1+R02*p2o1c2),m2*g0) ...
   +cross((R01*p1o0o1+R02*p2o1o2+R03*p3o2c3),m3*g0)+cross((R01*p1o0o1+R02*p2o1o2 ...
   +R03*p3o2o3+R04*p4o3c4),m4*g0),z00);
taustatic(2)=dot(cross(R02*p2o1c2,m2*g0)+cross((R02*p2o1o2+R03*p3o2c3),m3*g0) ...
   +cross((R02*p2o1o2+R03*p3o2o3+R04*p4o3c4),m4*g0),z01);
taustatic(3)=dot(cross(R03*p3o2c3,m3*g0)+cross((R03*p3o2o3+R04*p4o3c4),m4*g0),z02);
taustatic(4)=dot(cross(R04*p4o3c4,m4*g0),z03);
