function [M11,M12,M13,M14,M21,M22,M23,M24,M31,M32,M33,M34,M41,M42,M43,M44...
      ,V1,V2,V3,V4,G1,G2,G3,G4]=sub_static_vars(m,pCOM,ICOM,a,g)

% This function reads the symbolically-generated text files 
% representing each matrix and vector term in the LaGrangian
% dynamic model, substitutes the known constant values, creates
% string expressions for each, and places the strings into the 
% workspace for use in the SLaGrange function

% Read constant values from workspace into temp variables
m1=m(1);m2=m(2);m3=m(3);m4=m(4);

a1=a(1);a2=a(2);a3=a(3);a4=a(4);

p1x=pCOM(1,1);p1y=pCOM(1,2);p1z=pCOM(1,3);
p2x=pCOM(2,1);p2y=pCOM(2,2);p2z=pCOM(2,3);
p3x=pCOM(3,1);p3y=pCOM(3,2);p3z=pCOM(3,3);
p4x=pCOM(4,1);p4y=pCOM(4,2);p4z=pCOM(4,3);

I111=ICOM(1,1);I112=ICOM(1,2);I113=ICOM(1,3);
I121=ICOM(2,1);I122=ICOM(2,2);I123=ICOM(2,3);
I131=ICOM(3,1);I132=ICOM(3,2);I133=ICOM(3,3);

I211=ICOM(4,1);I212=ICOM(4,2);I213=ICOM(4,3);
I221=ICOM(5,1);I222=ICOM(5,2);I223=ICOM(5,3);
I231=ICOM(6,1);I232=ICOM(6,2);I233=ICOM(6,3);

I311=ICOM(7,1);I312=ICOM(7,2);I313=ICOM(7,3);
I321=ICOM(8,1);I322=ICOM(8,2);I323=ICOM(8,3);
I331=ICOM(9,1);I332=ICOM(9,2);I333=ICOM(9,3);

I411=ICOM(10,1);I412=ICOM(10,2);I413=ICOM(10,3);
I421=ICOM(11,1);I422=ICOM(11,2);I423=ICOM(11,3);
I431=ICOM(12,1);I432=ICOM(12,2);I433=ICOM(12,3);

% Replace elements of string expressions stored as text files 
% with known numerical quantities
symname=cellstr(['m1  ';'m2  ';'m3  ';'m4  ';'a1  ';'a2  ';'a3  ';'a4  ';'g   ';
   'p1x ';'p1y ';'p1z ';'p2x ';'p2y ';'p2z ';'p3x ';'p3y ';'p3z ';'p4x ';'p4y ';'p4z ';
   'I111';'I112';'I113';'I121';'I122';'I123';'I131';'I132';'I133';
   'I211';'I212';'I213';'I221';'I222';'I223';'I231';'I232';'I233';
   'I311';'I312';'I313';'I321';'I322';'I323';'I331';'I332';'I333';
   'I411';'I412';'I413';'I421';'I422';'I423';'I431';'I432';'I433']);

value=[m1;m2;m3;m4;a1;a2;a3;a4;g;
   p1x;p1y;p1z;p2x;p2y;p2z;p3x;p3y;p3z;p4x;p4y;p4z;
   I111;I112;I113;I121;I122;I123;I131;I132;I133;
   I211;I212;I213;I221;I222;I223;I231;I232;I233;
   I311;I312;I313;I321;I322;I323;I331;I332;I333;
   I411;I412;I413;I421;I422;I423;I431;I432;I433];

h=0;
for i=1:4
   for j=1:4
      h=h+1;
      fid=fopen(strcat(cd,'\symbolic manip\M',num2str(i),num2str(j),'.txt'),'r');
      Mij=fscanf(fid,'%c');
      fclose(fid);    
      for k=1:length(symname)
         Mij=strrep(Mij,symname(k),num2str(value(k)));
      end
      M{h}=Mij;
   end
   fid=fopen(strcat(cd,'\symbolic manip\V',num2str(i),'.txt'),'r');
   Vi=fscanf(fid,'%c');
   fclose(fid);
   fid=fopen(strcat(cd,'\symbolic manip\G',num2str(i),'.txt'),'r');
   Gi=fscanf(fid,'%c');
   fclose(fid);
   for k=1:length(symname)
      Vi=strrep(Vi,symname(k),num2str(value(k)));
      Gi=strrep(Gi,symname(k),num2str(value(k)));
   end
   V{i}=Vi;
   G{i}=Gi;
end

% Place output into workspace
M11=char(M{1});M12=char(M{2});M13=char(M{3});M14=char(M{4});
M21=char(M{5});M22=char(M{6});M23=char(M{7});M24=char(M{8});
M31=char(M{9});M32=char(M{10});M33=char(M{11});M34=char(M{12});
M41=char(M{13});M42=char(M{14});M43=char(M{15});M44=char(M{16});
V1=char(V{1});V2=char(V{2});V3=char(V{3});V4=char(V{4});
G1=char(G{1});G2=char(G{2});G3=char(G{3});G4=char(G{4});
if isempty(G1)
   G1='0'
end
